@@ -129,7 +129,7 @@ unwrap_rows <- function(mat, n) {
 #' @keywords internal
 download_data <- function(url, destdir = getwd(), timestamping = T, nc = F, verbose = F, progress = F) {
     
-    destdir <- normalizePath(destdir)
+    destdir <- normalizePath(paste0(destdir,"/."))
     destfile <- paste0(destdir, "/", basename(url))
     temp.file <- paste0(tempdir(), "/", basename(url))
     
@@ -142,8 +142,11 @@ download_data <- function(url, destdir = getwd(), timestamping = T, nc = F, verb
             timecondition = TRUE, timevalue = base::file.info(destfile)$mtime)
         hand <- curl::new_handle()
         curl::handle_setopt(hand, .list = opts)
-        tryCatch(status <- curl::curl_fetch_disk(url, path = temp.file, handle = hand), error = function(e) stop("Download of ", 
-            url, " failed!"))
+        tryCatch(status <- curl::curl_fetch_disk(url, path = temp.file, handle = hand), error = function(e) {
+          message("Download of ", 
+            url, " failed. Reverting to already cached file.")
+          return()
+          })
         if (file.info(temp.file)$size > 0) {
             file.copy(temp.file, destfile, overwrite = T)
         }
